/* xkeycaps, Copyright (c) 1991, 1992, 1993 Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the keycodes of the HP PC keyboard.
 * By Markus Stumpf <stumpf@informatik.tu-muenchen.de>
 */

static const KeyCode hppc_codes [] = {

  /* Row 0 */
  39,
  84, 83, 82, 81,
  89, 90, 91, 92,
  45, 41, 43, 47,
  80, 86, 15,

  /* Row 2 */
  71, 70, 69, 68, 67, 66, 65, 64, 96, 97, 98, 99, 100, 101,
  110, 118, 119,
  88, 25, 29, 31,

  /* Row 3 */
  63, 62, 61, 60, 59, 58, 57, 56, 104, 105, 106, 107, 108, 109,
  111, 125, 127,
  21, 17, 19, 27,
  
  /* Row 4 */
  55, 53, 52, 51, 50, 49, 48, 112, 113, 114, 115, 116, 117,
  16, 18, 20,

  /* Row 5 */
  13, 36, 35, 34, 33, 32, 128, 120, 121, 122, 123, 12,
  134,
  24, 26, 28, 23,

  /* Row 6 */
  14,
  11, 129, 10,
  8,
  132, 133, 135,
  30, 44
};
